@@ -3,7 +3,7 @@ context("build(hp) - ResNet")
 source("utils.R")
 
 test_succeeds("Can run hyper_class", {
-  library(keras)
+
   library(dplyr)
   library(kerastuneR)
   
@@ -12,7 +12,6 @@ test_succeeds("Can run hyper_class", {
   hypermodel = HyperResNet(input_shape = list(300L, 300L, 3L), classes = 10L)
   hypermodel2 = HyperXception(input_shape = list(300L, 300L, 3L), classes = 10L)
   
-  testthat::expect_match(hypermodel %>% capture.output(),'keras_tuner.applications.resnet.HyperResNet')
   
   tuner = Hyperband(
     hypermodel = hypermodel,
@@ -21,7 +20,6 @@ test_succeeds("Can run hyper_class", {
     directory = 'my_dir',
     project_name='helloworld')
   
-  testthat::expect_match(tuner %>% capture.output(),'keras_tuner.tuners.hyperband.Hyperband')
   
   train_data = cifar$train$x[1:30,1:32,1:32,1:3]
   test_data = cifar$train$y[1:30,1] %>% as.matrix()
